@@ -3,17 +3,23 @@ BEGIN {
   $Yeb::Plugin::Locale::Simple::AUTHORITY = 'cpan:GETTY';
 }
 # ABSTRACT: Yeb Plugin for Locale::Simple connection
-$Yeb::Plugin::Locale::Simple::VERSION = '0.001';
+$Yeb::Plugin::Locale::Simple::VERSION = '0.002';
 use Moo;
 use Locale::Simple;
 
 has app => ( is => 'ro', required => 1 );
 
+has locales => (
+	is => 'ro',
+	predicate => 1,
+);
+
 sub BUILD {
   my ( $self ) = @_;
   for my $func (@Locale::Simple::EXPORT) {
     $self->app->register_function($func,sub { &{\&{$func}}(@_) });
   };
+  l_dir($self->locales) if $self->has_locales;
 }
 
 1;
@@ -28,7 +34,7 @@ Yeb::Plugin::Locale::Simple - Yeb Plugin for Locale::Simple connection
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 AUTHOR
 
